#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2015  Marek Marczykowski-Górecki
#                       <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#

Name:           qubes-kernel-vm-support
Version:        4.1.18
Release:        1%{?dist}
Summary:        Qubes VM initramfs modules
Source0:        qubes-utils-%{version}.tar.gz

Group:          Qubes
Vendor:         Invisible Things Lab
License:        GPL v2 only
URL:            http://www.qubes-os.org

# qubes-prepare-vm-kernel interface version - to use in kernel.spec
Provides:       qubes-prepare-vm-kernel = 2
Requires:       dracut
Requires:       busybox
Requires:       e2fsprogs
BuildRequires:  make
BuildRequires:  gcc
BuildRequires:  e2fsprogs-devel

%description
This package contains:
1. Dracut module required to setup Qubes VM root filesystem. This package is
needed in VM only when the VM uses its own kernel (via pvgrub or so). Otherwise
initrd is provided by dom0.

%prep
%setup -q -n qubes-utils-%{version}

%build
make -C kernel-modules all

%install
make install-fedora-kernel-support DESTDIR=%{buildroot}

%files
/usr/lib/dracut/modules.d/90qubes-vm
/usr/lib/dracut/modules.d/90qubes-vm-modules
/usr/lib/dracut/modules.d/90qubes-vm-simple
/usr/lib/dracut/modules.d/80xen-scrub-pages
/usr/lib/qubes/vm-modules-genfs
/usr/sbin/qubes-prepare-vm-kernel
%config(noreplace) /etc/default/grub.qubes-kernel-vm-support

%triggerin -- grub2-tools
if ! grep -q '/etc/default/grub\.qubes-kernel-vm-support$' /etc/default/grub 2>/dev/null; then
    # do not keep Qubes-related settings directly in user-controlled config,
    # include another file
    echo '. /etc/default/grub.qubes-kernel-vm-support' >> /etc/default/grub
fi

%preun
if [ $1 -eq 0 ]; then
    if grep -q '/etc/default/grub\.qubes-kernel-vm-support$' /etc/default/grub 2>/dev/null; then
        sed -i -e '/grub\.qubes-kernel-vm-support$/d' /etc/default/grub
    fi
fi

%posttrans

# Rebuild all initramfs images to include updated modules
if [ -r /usr/share/qubes/marker-vm ] && [ -x /usr/bin/dracut ]; then
    ret=0
    for img in /boot/initramfs-*.img; do
        kver="${img#*initramfs-}"
        kver="${kver%.img}"
        dracut -f "$img" "$kver" || ret=$?
    done
    if [ "$ret" -eq 0 ]; then
        # "milestone" initramfs update version:
        # 1 - addition of xen scrub_pages enabling code
        echo 1 > /var/lib/qubes/initramfs-updated
    fi
fi

%changelog
* Sun Jan 15 2023 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-linux-utils.git

* Sun Jan 15 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 606675f
- version 4.1.18

* Sun Jan 15 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f992dfb
- dracut: detect VM based on file presence, no runtime query to qubesdb

* Sun Jan 15 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4efb322
- dracut: drop legacy xenstore-read qubes-vm-type

* Sun Jan 15 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 213bc99
- rpm: add e2fsprogs as qubes-prepare-vm-kernel dependency

* Mon Jan 09 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2df85b3
- version 4.1.17

* Mon Jan 09 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 67d253d
- rpm: provide virtual qubes-prepare-vm-kernel capability

* Mon Jan 09 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 864e176
- qubes-prepare-vm-kernel: make initramfs smaller

* Mon Jan 09 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - eeb4b2e
- qubes-prepare-vm-kernel: sync with pre-built package features

* Mon Jan 09 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5a8bf77
- Build and install vm-modules-genfs

* Mon Jan 09 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 322e822
- debian: do not install qubes-prepare-vm-kernel

* Mon Jan 09 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - e937e6b
- Add spaces after function names

* Mon Jan 09 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 215eabf
- Install and source grub.qubes-kernel-vm-support

* Mon Jan 09 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - d3638b0
- Ensure that /etc/default/grub is not empty

* Mon Jan 09 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 9a94528
- Add comments to /etc/default/grub

* Mon Jan 09 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - e999527
- Fix up /etc/default/grub in postinstall script

* Mon Jan 09 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 73dc20f
- Fix sed regex for mkinitcpio.conf

* Mon Jan 09 2023 Rusty Bird <rustybird@net-c.com> - 4c94b62
- initramfs: sector-size agnostic partitioning of volatile volume

* Mon Jan 09 2023 Rusty Bird <rustybird@net-c.com> - 28f6e45
- initramfs: remove unused variable

* Mon Jan 09 2023 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 2c4a3e7
- Drop Travis CI

* Mon Jan 09 2023 Gaurav <g.gupta@samsung.com> - 386aeb2
- Make use of static variables

* Wed Oct 20 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 506594e
- version 4.1.16

* Fri Oct 15 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 5be2b83
- spec: allow matching python3.10 in %files

* Fri Jun 18 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 07ea7b2
- version 4.1.15

* Thu May 13 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 308d708
- version 4.1.14

* Wed May 12 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 0209684
- Force exporting of loop devices

* Tue May 11 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 546e0c9
- Add do_unpack_ext to limit what can be unpacked

* Mon Apr 12 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - 54afa23
- Use a flexable array member instead of an empty array

* Fri Mar 12 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - c16c721
- kernel-vm-support: fix spec indentation

* Fri Mar 12 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - a26b504
- kernel-vm-support: add make as BR

* Fri Feb 05 2021 Shawn Anastasio <shawn@anastas.io> - ac0e7bb
- Makefile: remove broken 32-bit host check

* Thu Jan 07 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 72458b4
- version 4.1.13

* Wed Jan 06 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - 685d201
- Fix CI

* Tue Jan 05 2021 Demi Marie Obenour <athena@invisiblethingslab.com> - a8ca815
- Mass replace: ‘/var/run’ → ‘/run’

* Tue Jan 05 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1eff32a
- archlinux: add makedepends on qubes-vm-xen

* Wed Dec 23 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - e872754
- Validate remote filename before displaying it

* Wed Dec 23 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 87ead86
- Modernize systemd unit files

* Wed Dec 23 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - cf009e8
- Meminfo writer comes before user logins

* Fri Dec 18 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - befbd65
- Fix some links to more modern versions

* Sat Dec 12 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - a7e3632
- debian: update compat

* Sat Dec 12 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 6154498
- debian: update control

* Wed Dec 02 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8289227
- tests: fix IncompleteReadError exception location

* Wed Dec 02 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4ceee75
- ci: add coverage

* Wed Dec 02 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 04aacff
- gitlab-ci: add custom jobs

* Sun Nov 15 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 7160bc7
- Add .gitlab-ci.yml

* Fri Nov 13 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 53120a7
- version 4.1.12

* Thu Nov 12 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 01e69a7
- rpm,deb: /lib is a symlink to /usr/lib, move the files appropriately

* Thu Nov 12 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c5413af
- Set /dev/xen/* permissions early

* Mon Nov 02 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b124c71
- dracut: enable swap as early as possible

* Thu Oct 22 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - dab2c31
- travis: fix build/install jobs

* Thu Oct 22 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 81d3430
- debian: don't fail package install on missing /var/lib/qubes

